@@ -1,9 +1,11 @@
+from .generator_predefined_files import GeneratorPredefinedFiles
 from ..base.generator import GeneratorBase
 from ..base.generator_visitor import GeneratorVisitor
 from .generator_data_storage import GeneratorDataStorage
 from .generator_factory import GeneratorFactory
 from .generator_observer import GeneratorObserver
 from .generator_config import GeneratorConfig
+from ..core.class_ import Class
 
 
 class Generator(GeneratorBase):
@@ -12,9 +14,18 @@ class Generator(GeneratorBase):
         GeneratorBase.__init__(self)
 
     def generate(self, model):
+        self.generate_base_enum_class(model)
         GeneratorBase.generate(self, model)
         GeneratorDataStorage().generate(model)
         GeneratorVisitor().generate(model, False)
         GeneratorFactory().generate(model)
         GeneratorObserver().generate(model)
         GeneratorConfig().generate(model)
+        GeneratorPredefinedFiles().generate(model)
+
+    def generate_base_enum_class(self, model):
+        base_enum = Class()
+        base_enum.name = 'BaseEnum'
+        base_enum.type = 'class'
+        model.add_class(base_enum)
+
